@@ -640,7 +640,19 @@ int main(int argc, char *argv[])
 		    " If you have modified the default blocklist, you can ignore this message.");
 	}
 	SET_IF_GIVEN(zconf.allowlist_filename, allowlist_file);
-
+	zconf.validate_source_port_override = VALIDATE_SRC_PORT_UNSET_OVERRIDE;
+	if (args.validate_source_port_given) {
+		if (strcmp(args.validate_source_port_arg, "enable") == 0) {
+			// user wants to force source port validation
+			zconf.validate_source_port_override = VALIDATE_SRC_PORT_ENABLE_OVERRIDE;
+		} else if (strcmp(args.validate_source_port_arg, "disable") == 0) {
+			// user wants to force disable source port validation
+			zconf.validate_source_port_override = VALIDATE_SRC_PORT_DISABLE_OVERRIDE;
+		} else {
+			// unknown value
+			log_fatal("zmap", "unknown value for --validate-source-port, use either \"enable\" or \"disable\"");
+		}
+	}
 	if (zconf.probe_module->port_args) {
 		if (args.source_port_given) {
 			char *dash = strchr(args.source_port_arg, '-');
@@ -678,7 +690,7 @@ int main(int argc, char *argv[])
 					  zconf.packet_streams,
 					  zconf.source_port_first, zconf.source_port_last,
 					  (zconf.source_port_last - zconf.source_port_first) + 1);
-			} else if (((float)zconf.packet_streams / (float)num_source_ports) < 0.1) {
+			} else if (((float)zconf.packet_streams / (float)num_source_ports) > 0.1) {
 				log_warn("zmap", "ZMap is configured to use a relatively small number"
 						 " of source ports (fewer than 10x the number of probe packets per target ip/port),"
 						 " which limits the entropy that ZMap has available for "
@@ -793,7 +805,7 @@ int main(int argc, char *argv[])
 	if (zconf.default_mode) {
 		log_debug(
 		    "filter",
-		    "No output filter specified. Will use default: exclude duplicates and unssuccessful");
+		    "No output filter specified. Will use default: exclude duplicates and unsuccessful");
 	} else if (args.output_filter_given &&
 		   strcmp(args.output_filter_arg, "")) {
 		// Run it through yyparse to build the expression tree
